package com.njyunzhi.invoice.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.njyunzhi.invoice.common.BaseController;
import com.njyunzhi.invoice.common.ResponseBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.njyunzhi.invoice.service.ITaInvoiceItemTplService;
import com.njyunzhi.invoice.entity.TaInvoiceItemTpl;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 报销项目模板 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2022-07-04
 */

@Api(tags = "报销项目模板")
@RestController
@RequestMapping("/")
public class TaInvoiceItemTplController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaInvoiceItemTplController.class);

    @Autowired
    public ITaInvoiceItemTplService iTaInvoiceItemTplService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taInvoiceItemTpl",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taInvoiceItemTplList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
									 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{

		    IPage<TaInvoiceItemTpl> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaInvoiceItemTpl> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaInvoiceItemTpl> result = iTaInvoiceItemTplService.page(pg, queryWrapper);
            return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taInvoiceItemTpl 实体对象
     * @return
     */
    @RequestMapping(value="/taInvoiceItemTpl",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taInvoiceItemTplAdd(@ApiParam("保存内容") @RequestBody TaInvoiceItemTpl taInvoiceItemTpl) throws Exception{

        if (iTaInvoiceItemTplService.save(taInvoiceItemTpl)){
            return ResponseBean.success(taInvoiceItemTpl);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taInvoiceItemTpl/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taInvoiceItemTplDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        if(iTaInvoiceItemTplService.removeById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taInvoiceItemTpl 实体对象
     * @return
     */
    @RequestMapping(value="/taInvoiceItemTpl/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taInvoiceItemTplUpdate(@ApiParam("对象ID") @PathVariable Integer id,
                                        @ApiParam("更新内容") @RequestBody TaInvoiceItemTpl taInvoiceItemTpl) throws Exception{

        if (iTaInvoiceItemTplService.updateById(taInvoiceItemTpl)){
            return ResponseBean.success(iTaInvoiceItemTplService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taInvoiceItemTpl/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taInvoiceItemTplGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        return ResponseBean.success(iTaInvoiceItemTplService.getById(id));
    }
}
